@@ -49,6 +49,8 @@ pub mod import_map;
 
 #[cfg(test)]
 mod test_db;
+#[cfg(test)]
+mod macro_expansion_tests;
 
 use std::{
     hash::{Hash, Hasher},
@@ -733,7 +735,6 @@ fn macro_call_as_call_id(
             &|path: ast::Path| resolver(path::ModPath::from_src(db, path, &hygiene)?),
             error_sink,
         )
-        .map(MacroCallId::from)
     } else {
         Ok(def.as_lazy_macro(
             db.upcast(),
@@ -763,7 +764,7 @@ fn derive_macro_as_call_id(
         krate,
         MacroCallKind::Derive {
             ast_id: item_attr.ast_id,
-            derive_name: last_segment.to_string(),
+            derive_name: last_segment.to_string().into_boxed_str(),
             derive_attr_index: derive_attr.ast_index,
         },
     );
@@ -778,6 +779,7 @@ fn attr_macro_as_call_id(
     resolver: impl Fn(path::ModPath) -> Option<MacroDefId>,
 ) -> Result<MacroCallId, UnresolvedMacro> {
     let def: MacroDefId = resolver(item_attr.path.clone())
+        .filter(MacroDefId::is_attribute)
         .ok_or_else(|| UnresolvedMacro { path: item_attr.path.clone() })?;
     let last_segment = item_attr
         .path
@@ -799,7 +801,7 @@ fn attr_macro_as_call_id(
         krate,
         MacroCallKind::Attr {
             ast_id: item_attr.ast_id,
-            attr_name: last_segment.to_string(),
+            attr_name: last_segment.to_string().into_boxed_str(),
             attr_args: arg,
             invoc_attr_index: macro_attr.id.ast_index,
         },
